# atlassianhw

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

A collection of simple functions to help with the homework.

## Install

``` sh
pip install atlassianhw
```

## How to use

Simple way to load in the data using `AData()`:

``` python
for name, data in AData().raw_data.items():
    print(f'Data source: {name}')
    display(data.head())
```

    /Users/jasonorawe/Documents/py_wd/git/atlassianhw/atlassianhw/utils.py:22: FutureWarning: Inferring datetime64[ns] from data containing strings is deprecated and will be removed in a future version. To retain the old behavior explicitly pass Series(data, dtype=datetime64[ns])
      'employee_details': pd.read_excel(pkgutil.get_data(__name__, '_data/Employee_details.xlsx')),

    Data source: employee_details
    Data source: glossary
    Data source: manager_details
    Data source: manager_mapping
    Data source: promo_meta_data

<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
&#10;    .dataframe tbody tr th {
        vertical-align: top;
    }
&#10;    .dataframe thead th {
        text-align: right;
    }
</style>

|     | emp_id | Attrited | kudos_received_so_far | kudos_count_given_so_far | job_family           | tenure_in_days_new | level     | mnths_in_team | last_promotion_date |
|-----|--------|----------|-----------------------|--------------------------|----------------------|--------------------|-----------|---------------|---------------------|
| 0   | 1      | 0        | 5.157031              | 2                        | Software Engineering | 1065               | Junior IC | 35.0          | 2022-10-01          |
| 1   | 2      | 0        | 5.466410              | 9                        | Software Engineering | 1066               | Junior IC | 35.0          | 2022-04-01          |
| 2   | 3      | 0        | 4.744126              | 18                       | Program Management   | 1079               | Manager   | 19.0          | 2021-07-16          |
| 3   | 4      | 1        | 0.261903              | 0                        | Software Engineering | 154                | Director  | 6.0           | 2020-03-30          |
| 4   | 5      | 0        | 5.918518              | 8                        | Product Manager      | 1079               | Manager   | 35.0          | 2022-10-01          |

</div>
<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
&#10;    .dataframe tbody tr th {
        vertical-align: top;
    }
&#10;    .dataframe thead th {
        text-align: right;
    }
</style>

|     | Dataset                | Dataset info              | Column Name          | Description                  |
|-----|------------------------|---------------------------|----------------------|------------------------------|
| 0   | promo_meta_data        | historical promo metadata | level                | level of employee            |
| 1   | promo_meta_data        | historical promo metadata | months_for_promotion | months for promotion in past |
| 2   | Manager_mapping        | Manager mapping dataset   | mgr_id               | manager ID                   |
| 3   | Manager_mapping        | Manager mapping dataset   | emp_id               | employee id                  |
| 4   | Attrition_Manager_info | Manager meta data         | mgr_cum_churn_new    | total churns under manager   |

</div>
<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
&#10;    .dataframe tbody tr th {
        vertical-align: top;
    }
&#10;    .dataframe thead th {
        text-align: right;
    }
</style>

|     | mgr_id | mgr_cum_churn_new | Tenure_Mgr         | total_teams_mgr | exp_as_mgr |
|-----|--------|-------------------|--------------------|-----------------|------------|
| 0   | 7582.0 | 0.000000          | 6-12 mons          | 1.0             | 90.0       |
| 1   | 6132.0 | 6.136273          | 3-6 mons           | 2.0             | 1489.0     |
| 2   | 7306.0 | 0.000000          | More Than 10 years | 2.0             | 1124.0     |
| 3   | 3712.0 | 2.899962          | 1-2 years          | 8.0             | 579.0      |
| 4   | NaN    | 0.000000          | 0                  | 1.0             | 1489.0     |

</div>
<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
&#10;    .dataframe tbody tr th {
        vertical-align: top;
    }
&#10;    .dataframe thead th {
        text-align: right;
    }
</style>

|     | mgr_id | emp_id |
|-----|--------|--------|
| 0   | 7582.0 | 1      |
| 1   | 6132.0 | 2      |
| 2   | 7306.0 | 3      |
| 3   | 3712.0 | 4      |
| 4   | NaN    | 5      |

</div>
<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
&#10;    .dataframe tbody tr th {
        vertical-align: top;
    }
&#10;    .dataframe thead th {
        text-align: right;
    }
</style>

|     | level     | months_for_promotion |
|-----|-----------|----------------------|
| 0   | Junior IC | 37.0                 |
| 1   | Junior IC | 40.0                 |
| 2   | Manager   | 30.0                 |
| 3   | Director  | 37.0                 |
| 4   | Manager   | 34.0                 |

</div>
